@@ -9,9 +9,9 @@ use Fcntl;
 use File::MoreUtil qw(file_exists l_abs_path);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-06'; # DATE
+our $DATE = '2023-07-28'; # DATE
 our $DIST = 'File-Trash-FreeDesktop'; # DIST
-our $VERSION = '0.200'; # VERSION
+our $VERSION = '0.201'; # VERSION
 
 sub new {
     require File::HomeDir::FreeDesktop;
@@ -350,7 +350,7 @@ File::Trash::FreeDesktop - Trash files
 
 =head1 VERSION
 
-This document describes version 0.200 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2022-05-06.
+This document describes version 0.201 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-07-28.
 
 =head1 SYNOPSIS
 
@@ -566,11 +566,35 @@ Source repository is at L<https://github.com/perlancar/perl-File-Trash-FreeDeskt
 
 =head1 SEE ALSO
 
-[1] http://freedesktop.org/wiki/Specifications/trash-spec
+=head2 Specification
 
-Related modules on CPAN:
+L<https://freedesktop.org/wiki/Specifications/trash-spec>
 
-=over 4
+=head2 CLI utilities
+
+=over
+
+=item * App::TrashUtils
+
+A set of CLI's written in Perl: L<trash-empty>, L<trash-list>,
+L<trash-list-trashes>, L<trash-put>, L<trash-restore>, L<trash-rm>.
+
+=item * L<trash-u> (from App::trash::u)
+
+An alternative CLI, with undo support.
+
+=item * trash-cli
+
+A set of CLI's written in Python: C<trash-empty>, C<trash-list>, C<trash-put>,
+C<trash-restore>, C<trash-rm>.
+
+L<https://github.com/andreafrancia/trash-cli>
+
+=back
+
+=head2 Related CPAN modules
+
+=over
 
 =item * L<Trash::Park>
 
@@ -613,13 +637,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2017, 2015, 2014, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2017, 2015, 2014, 2012 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
